@@ -1,7 +1,6 @@
 import requests
 from datetime import datetime, timedelta
 from urllib.parse import urljoin
-
 from .base import SmartZoneBase
 
 
@@ -21,10 +20,6 @@ class SmartZoneClient(SmartZoneBase):
     def datetemp(self, date_range):
         a = int(date_range[0].timestamp()*1000)
         b = int(date_range[1].timestamp()*1000)
-        if (a > 0):
-            a += 1000
-        if (b > 0):
-            b += 1000
         date_range = (a, b)
         return date_range
 
@@ -424,7 +419,7 @@ class SmartZoneClient(SmartZoneBase):
 
     def trafficAnalysis_clientUsageWlan (self, filter_type, filter_value, date_range, interval='86400000', rate='tx+rx', frequence='2.4G+5G', page=1, limit=1000):
         '''clientUsageWlan return number total of clients in zone, name of device and total bytes consumed
-           Params: (self, filter_type, filter_value, date_range, interval='90000', rate='tx+rx', frequence='2.4G+5G', page=1, limit=1000)
+           Params: (self, filter_type, filter_value, date_range, interval='86400000', rate='tx+rx', frequence='2.4G+5G', page=1, limit=1000)
            Required: filter_type, filter_value and date_range
            Optional: interval, rate, frequence, page and limit
 
@@ -475,3 +470,111 @@ class SmartZoneClient(SmartZoneBase):
         url = self.endpoint('v8_2/trafficAnalysis/client/usage/wlan')
         r = self.session.post(url, json=json)
         return r.json()
+
+    def trafficAnalysis_lineUsageWlan (self, filter_type, filter_value, date_range, interval='86400000', rate='tx+rx', frequence='2.4G+5G', page=1, limit=1000):
+        '''lieUsageWlan return consume total in zone per interval           
+           Params: (self, filter_type, filter_value, date_range, interval='86400000', rate='tx+rx', frequence='2.4G+5G', page=1, limit=1000)
+           Required: filter_type, filter_value and date_range
+           Optional: interval, rate, frequence, page and limit
+
+           filter_type & filter_value:
+                --------------------------------------------------------------------------
+               |TYPE(type)|    Value    |    Example(value)                               |
+               |--------------------------------------------------------------------------|
+               |AP        |apMac        |{AP, 11:22:33:44:55:66}                          |
+               |APGROUP   |apGroupId    |{APGROUP, 758b6970-032a-11e7-9e78-0a0027000000}  |
+               |CLIENT    |clientMac    |{CLIENT, AB:CD:00:00:00:03}                      |
+               |DOMAIN    |domainId     |{DOMAIN, 8b2081d5-9662-40d9-a3db-2a3cf4dde3f7}   |
+               |INDOORMAP |indoorMapId  |{INDOORMAP, 08733520-0a32-11e7-89a3-0a0027000000}|
+               |WLAN      |wlanId       |{WLAN, 1}                                        |
+               |ZONE      |zoneId       |{ZONE, 91fa3fe0-03da-11e7-8d82-0a0027000000}     |
+                --------------------------------------------------------------------------
+            frequence: 2.4G, 5G or 2.4G+5G
+            rate: tx, rx or tx+rx
+            interval: interval in mileseconds
+            limit: num of limite itens on page
+            page: number os pages
+        '''
+        date_range = self.datetemp(date_range)
+        json ={
+                "filters":[{
+                    "type": filter_type,
+                    "value": filter_value
+                }],
+                "extraFilters":[{
+                    "type":"RADIOID",
+                    "value": frequence
+                    }],
+                "extraNotFilters":[{
+                    "type":"MONITORINGENABLED",
+                    "value":"true"
+                    }],
+                "attributes":[
+                    rate,
+                    "Host_Name"
+                    ],
+                "extraTimeRange":{
+                    "start": date_range[0],
+                    "end": date_range[1],
+                    "interval": interval},
+                "options":{
+                    },
+                "limit": limit,
+                "page":page}
+        url = self.endpoint('v8_2/trafficAnalysis/line/usage/wlan')
+        r = self.session.post(url, json=json)
+        return r.json()
+
+    def trafficAnalysis_lineUsageSplitTunnel (self, filter_type, filter_value, date_range, interval='86400000', rate='tx+rx', frequence='2.4G+5G', page=1, limit=1000):
+        '''lieUsageSplitTunnel
+           Params: (self, filter_type, filter_value, date_range, interval='86400000', rate='tx+rx', frequence='2.4G+5G', page=1, limit=1000)
+           Required: filter_type, filter_value and date_range
+           Optional: interval, rate, frequence, page and limit
+
+           filter_type & filter_value:
+                --------------------------------------------------------------------------
+               |TYPE(type)|    Value    |    Example(value)                               |
+               |--------------------------------------------------------------------------|
+               |AP        |apMac        |{AP, 11:22:33:44:55:66}                          |
+               |APGROUP   |apGroupId    |{APGROUP, 758b6970-032a-11e7-9e78-0a0027000000}  |
+               |CLIENT    |clientMac    |{CLIENT, AB:CD:00:00:00:03}                      |
+               |DOMAIN    |domainId     |{DOMAIN, 8b2081d5-9662-40d9-a3db-2a3cf4dde3f7}   |
+               |INDOORMAP |indoorMapId  |{INDOORMAP, 08733520-0a32-11e7-89a3-0a0027000000}|
+               |WLAN      |wlanId       |{WLAN, 1}                                        |
+               |ZONE      |zoneId       |{ZONE, 91fa3fe0-03da-11e7-8d82-0a0027000000}     |
+                --------------------------------------------------------------------------
+            frequence: 2.4G, 5G or 2.4G+5G
+            rate: tx, rx or tx+rx
+            interval: interval in mileseconds
+            limit: num of limite itens on page
+            page: number os pages
+        '''
+        date_range = self.datetemp(date_range)
+        json ={
+                "filters":[{
+                    "type": filter_type,
+                    "value": filter_value
+                }],
+                "extraFilters":[{
+                    "type":"RADIOID",
+                    "value": frequence
+                    }],
+                "extraNotFilters":[{
+                    "type":"MONITORINGENABLED",
+                    "value":"true"
+                    }],
+                "attributes":[
+                    rate,
+                    "Host_Name"
+                    ],
+                "extraTimeRange":{
+                    "start": date_range[0],
+                    "end": date_range[1],
+                    "interval": interval},
+                "options":{
+                    },
+                "limit": limit,
+                "page":page}
+        url = self.endpoint('v8_2/trafficAnalysis/line/usage/splitTunnel/wlan')
+        r = self.session.post(url, json=json)
+        return r.json()
